==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:12+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sv_SE\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Affärs kontakt data"

, "Organisation / Unit"
: "Orginasition / Enhet"

, "Business Address"
: "Affärs adresser"

, "Email"
: "E-post"

, "Telephone Work"
: "Telefon Arbete"

, "Telephone Cellphone"
: "Telefon Mobiltelefon"

, "Telephone Car"
: "Telefon Bil"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Telefon Sida"

, "URL"
: "URL"

, "Role"
: "Roll"

, "Room"
: "Rum"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent Telefon"

, "Private Contact Data"
: "Privat Kontakt Data"

, "Private Address"
: "Privat Adress"

, "Email Home"
: "E-post hem"

, "Telephone Home"
: "Telefon Hem"

, "Telephone Cellphone Private"
: "Telefon Mobiltelefon Privat"

, "Telephone Fax Home"
: "Telefon Fax Hem"

, "URL Home"
: "URL hem"

, "Other Data"
: "Andra Data"

, "Birthday"
: "Födelsedag"

, "Job Title"
: "Arbets namn"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lista"
 ,"Listor"

]
, "Percent"
: ""

, "Description"
: "Beskrivning"

, "Members"
: "Medlemmar"

, "Type"
: "Typ"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Adressbok"
 ,"Adressböcker"

]
, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakter"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Land"

, "City"
: "Stad"

, "Postalcode"
: "Postkod"

, "Region"
: "Region"

, "Street"
: "Gata"

, "Street 2"
: "Gata 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Land (Privat)"

, "City (private)"
: "Stad (Privat)"

, "Postalcode (private)"
: "Postkod (Privat)"

, "Region (private)"
: "Region (Privat)"

, "Street (private)"
: "Gata (Privat)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "E-post (privat)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geografisk"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Notifiering"

, "Last Name"
: "Efternamn"

, "Display Name"
: "Visnings Namn"

, "Full Name"
: "Helt Namn"

, "First Name"
: "Första Namn"

, "Middle Name"
: "Mellan Namn"

, "Title"
: "Titel"

, "Suffix"
: "Ändelse"

, "Company"
: "Företag"

, "Unit"
: "Enhet"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Arbetar Roll"

, "Salutation"
: "Hälsning"

, "syncBackendIds"
: ""

, "Car phone"
: "Bil telefon"

, "Mobile"
: "Mobil"

, "Mobile (private)"
: "Mobil (Privat)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (Privat)"

, "Phone (private)"
: "Telefon (Privat)"

, "Pager"
: "Personsökare"

, "Phone"
: "Telefon"

, "Timezone"
: "Tidszon"

, "Web"
: "Webb"

, "URL (private)"
: "URL (privat)"

, "Label"
: ""

, "Lists"
: "Listor"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Kontakt Information"

, "Company Address"
: "Företags Adress"

, "New Contact"
: "Ny Kontakt"

, "ID"
: ""

, "Name"
: "Namn"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importera kontakter"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privat"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Taggar"

, "List Roles"
: ""

, "Street (Company Address)"
: "Gata (Företags Adress)"

, "Street 2 (Company Address)"
: "Gata 2 (Företags Adress)"

, "City (Company Address)"
: "Stad (Företags Adress)"

, "Region (Company Address)"
: "Region (Företags Adress)"

, "Postal Code (Company Address)"
: "Postkod (Företags Adress)"

, "Country (Company Address)"
: "Land (Företags Adress)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Gata (Privat Adress)"

, "Street 2 (Private Address)"
: "Gata 2 (Privat Adress)"

, "City (Private Address)"
: "Stad (Privat Adress)"

, "Region (Private Address)"
: "Region (Privat Adress)"

, "Postal Code (Private Address)"
: "Postkod (Privat Adress)"

, "Country (Private Address)"
: "Land (Privat Adress)"

, "Company Communication"
: "Företags Kommunikation"

, "Private Communication"
: "Privat Kommunikation"

, "E-Mail"
: "E-Post"

, "E-Mail (private)"
: "E-Post (Privat)"

, "Web (private)"
: "Webb (privat)"

, "Contacts"
: "Kontakter"

, "Addressbooks"
: "Adressböcker"

, "User Account"
: "Användar konto"

, "Quick Search"
: ""

, "Postal Code"
: "Postkod"

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Creation Time"
: "Skapad Tid"

, "Created By"
: "Skapad av"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Skriv beskrivning"

, "{0} must be given"
: ""

, "Member of List"
: "Medlem av Lista"

, "Map"
: "Karta"

, "Company address"
: "Företags adress"

, "Private address"
: "Privat adress"

, "CardDAV URL"
: "CardDAV URL"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Personlig Information"

, "Parse address"
: "Analysera adress"

, "Print contact"
: "Skriv ut kontakt"

, "Paste address"
: "Analysera adress"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Infoga en adress eller URI till ett vCard som ska importeras: "

, "Failed to parse address!"
: "Import av adress misslyckades!"

, "The address could not be read."
: "Adressen kunde inte läsas."

, "End token mode"
: "Avsluta tecken läge"

, "Remove Member"
: "Ta bort medlem"

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: "Sök efter användare ..."

, "Search for Contacts ..."
: "Sök efter kontakter ..."

, "All contacts"
: "Alla kontakter"

, "Default Addressbook"
: "Standard Adressbok"

, "The default addressbook for new contacts"
: "Standard adressboken för nya kontakter"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on addressbook startup"
: "Standardinställningen favoriten som laddas vid addressbook start"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Kontakta duplicerade check områden"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Dessa fält kontrolleras när en ny kontakt skapas. Om en post med samma data inom de områden hittas, en dubblett undantag skapas."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Kontakt hälsningsfraser tillgängliga"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Möjliga kontakt hälsningar. Observera att ytterligare värden kan påverka andra adressböcker på export eller synkronisering."

, "Mr"
: "Mr"

, "Ms"
: "Ms"

, "Parsing rules for addresses"
: "Parsing regler för adresser"

, "Path to a XML file with address parsing rules."
: "Väg till en XML-fil med adress parsing regler."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Kontakt VCARD import"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kontakter importerade på  ###CURRENTDATE### vid ###CURRENTTIME### av ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Tyska"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Kontakt CSV import från Outlook adress bok"

, "Contact CSV import from mac address book"
: "Kontakt CSV import"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importera kontakter från Google adressbok"

, "manage shared addressbooks"
: "hantera delade adressböcker"

, "Create new shared addressbook folders"
: "Skapa nya delade adressböcker-mappar"

, "manage shared addressbook favorites"
: "hantera delade adressboks favoriter"

, "Create or update shared addressbook favorites"
: "Skapa eller uppdatera delade adressboks favoriter"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s personliga adressbok"

, "All contacts I have read grants for"
: "Alla kontakter Jag har Läsrättigheter för"

, "My company"
: "Mitt företag"

, "All coworkers in my company"
: "Alla medarbetare i mitt företag"

, "My contacts"
: "Mina kontakter"

, "All contacts in my Addressbooks"
: "Alla kontakter i mina Adressböcker"

, "Last modified by me"
: "Senast ändrad av mig"

, "All contacts that I have last modified"
: "Alla kontakter som Jag senast har ändrat"

, "Internal Contacts"
: "Interna Kontakter"

, "List"
: "Lista"

, "Addressbook"
: "Adressbok"

, "Contact"
: "Kontakt"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Karta"

, "Preferred Address"
: ""

, "Personal Information"
: "Personlig Information"

, "Salutation"
: "Hälsning"

, "Title"
: "Titel"

, "Short Name"
: ""

, "First Name"
: "Första Namn"

, "Middle Name"
: "Mellan Namn"

, "Last Name"
: "Efternamn"

, "Company"
: "Företag"

, "Unit"
: "Enhet"

, "Display Name"
: "Visnings Namn"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Arbets namn"

, "Birthday (private)"
: ""

, "Contact Information"
: "Kontakt Information"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (Privat)"

, "Mobile (private)"
: "Mobil (Privat)"

, "Fax (private)"
: "Fax (Privat)"

, "E-Mail"
: "E-Post"

, "E-Mail (private)"
: "E-Post (Privat)"

, "Web"
: "Webb"

, "Company Address"
: "Företags Adress"

, "Street"
: "Gata"

, "Street 2"
: "Gata 2"

, "Region"
: "Region"

, "Postal Code"
: "Postkod"

, "City"
: "Stad"

, "Country"
: "Land"

, "Private Address"
: "Privat Adress"

, "Description"
: "Beskrivning"

, "Enter description"
: "Skriv beskrivning"

, "Groups"
: "Grupper"

, "Parse address"
: "Analysera adress"

, "Print contact"
: "Skriv ut kontakt"

, "Paste address"
: "Analysera adress"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Infoga en adress eller URI till ett vCard som ska importeras: "

, "Failed to parse address!"
: "Import av adress misslyckades!"

, "The address could not be read."
: "Adressen kunde inte läsas."

, "End token mode"
: "Avsluta tecken läge"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: "Sök efter grupper ..."

, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakter"

]
, "Members"
: "Medlemmar"

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: "Ta bort medlem"

, "CardDAV URL"
: "CardDAV URL"

, "New Contact"
: "Ny Kontakt"

, "Addressbook, Addressbooks"
: [
  "Adressbok"
 ,"Adressböcker"

]
, "ID"
: ""

, "Name"
: "Namn"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Privat"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: "Lista funktioner"

, "Suffix"
: "Ändelse"

, "Birthday"
: "Födelsedag"

, "Job Role"
: "Arbetar Roll"

, "Room"
: "Rum"

, "Street (Company Address)"
: "Gata (Företags Adress)"

, "Street 2 (Company Address)"
: "Gata 2 (Företags Adress)"

, "City (Company Address)"
: "Stad (Företags Adress)"

, "Region (Company Address)"
: "Region (Företags Adress)"

, "Postal Code (Company Address)"
: "Postkod (Företags Adress)"

, "Country (Company Address)"
: "Land (Företags Adress)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Gata (Privat Adress)"

, "Street 2 (Private Address)"
: "Gata 2 (Privat Adress)"

, "City (Private Address)"
: "Stad (Privat Adress)"

, "Region (Private Address)"
: "Region (Privat Adress)"

, "Postal Code (Private Address)"
: "Postkod (Privat Adress)"

, "Country (Private Address)"
: "Land (Privat Adress)"

, "Company Communication"
: "Företags Kommunikation"

, "Private Communication"
: "Privat Kommunikation"

, "Web (private)"
: "Webb (privat)"

, "Contacts"
: "Kontakter"

, "Addressbooks"
: "Adressböcker"

, "User Account"
: "Användar konto"

, "Quick Search"
: ""

, "Type"
: "Typ"

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Creation Time"
: "Skapad Tid"

, "Created By"
: "Skapad av"

, "List, Lists"
: [
  "Lista"
 ,"Listor"

]
, "Lists"
: "Listor"

, "Email Address, Email Addresses"
: [
  "E-postadress"
 ,"E-postadresser"

]
, "Email Addresses"
: "E-postadresser"

, "Quick search"
: "Snabb sök"

, "List Function, List Functions"
: [
  "Lista funktion"
 ,"Lista funktioner"

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Importera kontakter"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Taggar"

, "Full Name"
: "Helt Namn"

, "Postalcode"
: "Postkod"

, "Street (private)"
: "Gata (Privat)"

, "City (private)"
: "Stad (Privat)"

, "Region (private)"
: "Region (Privat)"

, "Postalcode (private)"
: "Postkod (Privat)"

, "Country (private)"
: "Land (Privat)"

, "Email"
: "E-post"

, "Car phone"
: "Bil telefon"

, "Pager"
: "Personsökare"

, "Email (private)"
: "E-post (privat)"

, "URL (private)"
: "URL (privat)"

, "Note"
: "Notifiering"

, "Timezone"
: "Tidszon"

, "Geo"
: "Geografisk"

, "Select list"
: ""

, "Search for users ..."
: "Sök efter användare ..."

, "Search for Contacts ..."
: "Sök efter kontakter ..."

, "Company address"
: "Företags adress"

, "Private address"
: "Privat adress"

, "Member E-Mails"
: ""

, "System Group"
: "Systemgrupp"

, "Group"
: "Grupp"

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Alla kontakter"

, "Default Addressbook"
: "Standard Adressbok"

, "The default addressbook for new contacts"
: "Standard adressboken för nya kontakter"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on addressbook startup"
: "Standardinställningen favoriten som laddas vid addressbook start"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Kontakta duplicerade check områden"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Dessa fält kontrolleras när en ny kontakt skapas. Om en post med samma data inom de områden hittas, en dubblett undantag skapas."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Kontakt hälsningsfraser tillgängliga"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Möjliga kontakt hälsningar. Observera att ytterligare värden kan påverka andra adressböcker på export eller synkronisering."

, "Mr"
: "Mr"

, "Ms"
: "Ms"

, "Parsing rules for addresses"
: "Parsing regler för adresser"

, "Path to a XML file with address parsing rules."
: "Väg till en XML-fil med adress parsing regler."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: "Avdelning"

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s personliga adressbok"

, "Business Contact Data"
: "Affärs kontakt data"

, "Organisation / Unit"
: "Orginasition / Enhet"

, "Business Address"
: "Affärs adresser"

, "Telephone Work"
: "Telefon Arbete"

, "Telephone Cellphone"
: "Telefon Mobiltelefon"

, "Telephone Car"
: "Telefon Bil"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Telefon Sida"

, "URL"
: "URL"

, "Role"
: "Roll"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent Telefon"

, "Private Contact Data"
: "Privat Kontakt Data"

, "Email Home"
: "E-post hem"

, "Telephone Home"
: "Telefon Hem"

, "Telephone Cellphone Private"
: "Telefon Mobiltelefon Privat"

, "Telephone Fax Home"
: "Telefon Fax Hem"

, "URL Home"
: "URL hem"

, "Other Data"
: "Andra Data"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: "PDF detaljer"

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Kontakt CSV import från Outlook adress bok"

, "Contact CSV import from mac address book"
: "Kontakt CSV import"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Tyska"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Kontakt VCARD import"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kontakter importerade på  ###CURRENTDATE### vid ###CURRENTTIME### av ###USERFULLNAME###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importera kontakter från Google adressbok"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: "Gata 2 (privat)"

, "Longitude (private)"
: "Longitud (privat)"

, "Latitude (private)"
: "Latitud (privat)"

, "Assistent"
: ""

, "Calendar URI"
: "Kalender URI"

, "Free/Busy URI"
: "Ledig/Upptagen URI"

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Interna Kontakter"

, "All contacts I have read grants for"
: "Alla kontakter Jag har Läsrättigheter för"

, "My company"
: "Mitt företag"

, "All coworkers in my company"
: "Alla medarbetare i mitt företag"

, "My contacts"
: "Mina kontakter"

, "All contacts in my Addressbooks"
: "Alla kontakter i mina Adressböcker"

, "Last modified by me"
: "Senast ändrad av mig"

, "All contacts that I have last modified"
: "Alla kontakter som Jag senast har ändrat"

, "All Contacts"
: "Alla kontakter"

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "hantera delade adressböcker"

, "Create new shared addressbook folders"
: "Skapa nya delade adressböcker-mappar"

, "manage shared addressbook favorites"
: "hantera delade adressboks favoriter"

, "Create or update shared addressbook favorites"
: "Skapa eller uppdatera delade adressboks favoriter"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""


]
, "Industry"
: ""

, "Contact"
: "Kontakt"

, "Addressbook"
: "Adressbok"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "Lista"

, "Email Address"
: "E-postadress"

, "List Function"
: "Lista funktion"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
